@@ -21,7 +21,7 @@ from humanfriendly import format_size
 
 
 __author__ = 'Erik Moqvist'
-__version__ = '16.4.0'
+__version__ = '16.5.0'
 
 
 DEFAULT_WORD_SIZE_BITS = 8
@@ -1672,9 +1672,9 @@ def _main():
         action='append',
         default=[],
         type=_convert_input_format_type,
-        help=('Input format auto, srec, ihex, ti_txt, or binary (default: auto). This '
-              'argument may be repeated, selecting the input format for each '
-              'input file.'))
+        help=('Input format auto, srec, ihex, ti_txt, or binary[,<address>] '
+              '(default: auto). This argument may be repeated, selecting the '
+              'input format for each input file.'))
     subparser.add_argument(
         '-o', '--output-format',
         default='hexdump',
